{% if not embedded -%}
{% include "bash.sh.j2" %}
{% endif %}

{% macro all(cache_only=False) -%}
{% import 'yq.sh.j2' as yq -%}
{{ yq.yq(cache_only) }}

{% import 'yj.sh.j2' as yj -%}
{{ yj.yj(cache_only) }}

{% import 'containerd.sh.j2' as containerd -%}
{{ containerd.containerd(cache_only) }}

{% import 'runc.sh.j2' as runc -%}
{{ runc.runc(cache_only) }}

{% import "kubectl.sh.j2" as kubectl %}
{{ kubectl.kubectl(cache_only) }}

{% import "nerdctl.sh.j2" as nerdctl %}
{{ nerdctl.nerdctl(cache_only) }}

{% import "kubeadm-init.sh.j2" as kubeadm %}
{{ kubeadm.kubeadm(cache_only) }}

{% import "buildkit.sh.j2" as buildkit %}
{{ buildkit.buildkit(cache_only) }}
{% endmacro %}


{% block content %}

{% if cache_only %}
rm -f archive.tar
{% else %}
if [[ -f archive.tar ]]; then
    tar xvf archive.tar
fi
{% endif %}
{{ all(cache_only) }}
{% endblock %}
